@@ -288,16 +288,13 @@ class Polynomial:
         if not num:  # pragma: no cover
             raise Exception("%s/%s" % (len(num), shift))
 
-        offset = 0
-
-        for item in num:
-            if item != 0:
+        for offset in range(len(num)):
+            if num[offset] != 0:
                 break
+        else:
             offset += 1
 
-        self.num = [0] * (len(num) - offset + shift)
-        for i in range(len(num) - offset):
-            self.num[i] = num[i + offset]
+        self.num = num[offset:] + [0] * shift
 
     def __getitem__(self, index):
         return self.num[index]
@@ -324,8 +321,6 @@ class Polynomial:
 
         ratio = glog(self[0]) - glog(other[0])
 
-        num = self[:]
-
         num = [
             item ^ gexp(glog(other_item) + ratio)
             for item, other_item in zip(self, other)]
